/*
 * Only officially supported way to build modules for 2.5.x kernels
 * is using FULL kernel source and do 
 *    make -C /lib/modules/`uname -r`/build SUBDIRS=$(PWD) modules
 *
 * As we do not require users to have full configured kernel sources (yet),
 * let's cheat... 
 * 
 * Problem is that kernel makefiles add -Iinclude/asm/mach-* to compiler
 * command line, to find machine specific configuration values. And
 * unfortunately header <asm/irq.h>, which we indirectly include, just
 * does #include "irq_vectors.h" - but this file occurs only in machine
 * specific directories.
 *
 * Instead of adding machine specific directory to the include path,
 * just use this simple placeholder which includes correct irq_vectors.h.
 *
 * Only important constant in this file is NR_IRQS, and as NR_IRQS is
 * same for everybody except Voyager, create only two branches -
 * - voyager and everybody else.
 */
#ifdef CONFIG_X86_VOYAGER
#include <asm/mach-voyager/irq_vectors.h>
#else
#include <asm/mach-default/irq_vectors.h>
#endif
